@@ -315,15 +315,18 @@ GdkPixmap *
 make_root_pixmap (gint width, gint height)
 {
 	Pixmap result;
+	Display *display;
 
 	gdk_flush ();
 
-	XSetCloseDownMode (gdk_display, RetainPermanent);
+	display = XOpenDisplay (gdk_display_name);
+	XSetCloseDownMode (display, RetainPermanent);
 
-	result = XCreatePixmap (gdk_display,
-				DefaultRootWindow (gdk_display),
+	result = XCreatePixmap (display,
+				DefaultRootWindow (display),
 				width, height,
 				DefaultDepthOfScreen (DefaultScreenOfDisplay (GDK_DISPLAY())));
+	XCloseDisplay (display);
 
 	return gdk_pixmap_foreign_new (result);
 }
@@ -357,37 +360,49 @@ set_root_pixmap (GdkPixmap *pixmap)
 	gulong nitems, bytes_after;
 	gint format;
 	guchar *data_esetroot;
-	Pixmap pixmap_id = GDK_WINDOW_XWINDOW (pixmap);
+	Pixmap pixmap_id;
+	int result;
 
 	XGrabServer (GDK_DISPLAY());
 
-	XGetWindowProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			    gdk_atom_intern("ESETROOT_PMAP_ID", FALSE),
-			    0L, 1L, False, XA_PIXMAP,
-			    &type, &format, &nitems, &bytes_after,
-			    &data_esetroot);
+	result = XGetWindowProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
+				     gdk_atom_intern("ESETROOT_PMAP_ID", FALSE),
+				     0L, 1L, False, XA_PIXMAP,
+				     &type, &format, &nitems, &bytes_after,
+				     &data_esetroot);
 
-	if (type == XA_PIXMAP) {
-		if (format == 32 && nitems == 4)
-			XKillClient(GDK_DISPLAY(), *((Pixmap*)data_esetroot));
+	if (result == Success && type == XA_PIXMAP && format == 32 && nitems == 1) {
+		XKillClient(GDK_DISPLAY(), *(Pixmap*)data_esetroot);
+	}
 
+	if (data_esetroot != NULL) {
 		XFree (data_esetroot);
 	}
 
-	XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			 gdk_atom_intern("ESETROOT_PMAP_ID", FALSE), XA_PIXMAP,
-			 32, PropModeReplace,
-			 (guchar *) &pixmap_id, 1);
-	XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			 gdk_atom_intern("_XROOTPMAP_ID", FALSE), XA_PIXMAP,
-			 32, PropModeReplace,
-			 (guchar *) &pixmap_id, 1);
+	if (pixmap != NULL) {
+		pixmap_id = GDK_WINDOW_XWINDOW (pixmap);
+
+		XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
+				 gdk_atom_intern("ESETROOT_PMAP_ID", FALSE), 
+				 XA_PIXMAP, 32, PropModeReplace,
+				 (guchar *) &pixmap_id, 1);
+		XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
+				 gdk_atom_intern("_XROOTPMAP_ID", FALSE), 
+				 XA_PIXMAP, 32, PropModeReplace,
+				 (guchar *) &pixmap_id, 1);
+
+		XSetWindowBackgroundPixmap (GDK_DISPLAY(), GDK_ROOT_WINDOW(), 
+					    pixmap_id);
+	} else {
+		XDeleteProperty (GDK_DISPLAY (), GDK_ROOT_WINDOW (),
+				 gdk_atom_intern("ESETROOT_PMAP_ID", FALSE));
+		XDeleteProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
+				 gdk_atom_intern("_XROOTPMAP_ID", FALSE));
+	}
 
-	XSetWindowBackgroundPixmap (GDK_DISPLAY(), GDK_ROOT_WINDOW(), pixmap_id);
 	XClearWindow (GDK_DISPLAY (), GDK_ROOT_WINDOW ());
-
 	XUngrabServer (GDK_DISPLAY());
-	
+
 	XFlush(GDK_DISPLAY());
 }
 
