@@ -789,23 +789,9 @@ page_show_callback (void)
 void
 help_callback (void)
 {
-
-  gchar *tmp;
-
-  tmp = gnome_help_file_find_file ("control-center", "desktop-intro.html#GCCSCREEN");
-  if (tmp) {
-          gnome_help_goto(0, tmp);
-          g_free(tmp);
-  } else {
-          GtkWidget *mbox;
-
-          mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-                                       GNOME_MESSAGE_BOX_ERROR,
-                                       _("Close"), NULL);
-
-          gtk_widget_show(mbox);
-  }
-
+    GnomeHelpMenuEntry help_entry= {"control-center",
+    "desktop-intro.html#GCCSCREEN"};
+    gnome_help_display (NULL, &help_entry);
 }
 void
 try_callback (void)
