@@ -681,21 +681,10 @@ ui_do_revert(GtkWidget *w, SoundProps *props)
 static void
 ui_do_help(void)
 {
-  gchar *tmp;
+    GnomeHelpMenuEntry help_entry= {"control-center",
+    "multimedia-intro.html#MULTIMEDIA-SOUND"};
+    gnome_help_display (NULL, &help_entry);
 
-  tmp = gnome_help_file_find_file ("control-center", "multimedia-intro.html#MULTIMEDIA-SOUND");
-  if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
-  } else {
-      GtkWidget *mbox;
-
-      mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-                                   GNOME_MESSAGE_BOX_ERROR,
-                                   _("Close"), NULL);
-
-      gtk_widget_show(mbox);
-  }
 }
 
 static void
