@@ -355,21 +355,9 @@ click_preview(GtkWidget *widget, gpointer data)
 static void
 click_help(GtkWidget *widget, gpointer data)
 {
-  gchar *tmp;
-
-  tmp = gnome_help_file_find_file ("control-center", "desktop-intro.html#GCCTHEME");
-  if (tmp) {
-    gnome_help_goto(0, tmp);
-    g_free(tmp);
-  } else {
-    GtkWidget *mbox;
-
-    mbox = gnome_message_box_new(_("No help is available/installed for these settings. Please make sure you\nhave the GNOME User's Guide installed on your system."),
-				 GNOME_MESSAGE_BOX_ERROR,
-				 _("Close"), NULL);
-    
-    gtk_widget_show(mbox);
-  }
+    GnomeHelpMenuEntry help_entry= {"control-center",
+    "desktop-intro.html#GCCTHEME"};
+    gnome_help_display (NULL, &help_entry);
 }
 static void
 click_try(GtkWidget *widget, gpointer data)
