@@ -4,6 +4,7 @@
 #include "callbacks.h"
 #include "control-center.h"
 #include <gnome.h>
+#include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkx.h>
 #include "gtk-multiview.h"
 
@@ -12,6 +13,7 @@ extern GtkWidget *multiview;
 extern GtkWidget *splash_screen;
 extern GtkWidget *hack_widget;
 extern GtkWidget *help_menu_item;
+extern GtkWidget *main_window;
 
 extern gchar *ior;
 static gint page_count = 0;
@@ -48,6 +50,17 @@ static void shutdown_capplet (node_data *nd);
 static void capplet_close_callback (GtkWidget *widget, gpointer data);
 static void capplet_close_callback2 (GtkWidget *widget, gpointer data);
 
+static void
+splash_size_allocate (GtkWidget *splash, GtkAllocation *alloc)
+{
+        static gint x = 0;
+        static gint y = 0;
+
+        x = MAX (x, GTK_WIDGET (splash)->requisition.width);
+        y = MAX (y, GTK_WIDGET (splash)->requisition.height);
+}
+
+
 node_data *
 find_node_by_id (gint id)
 {
@@ -149,7 +162,10 @@ launch_capplet (node_data *data, gboolean exec_new)
         /* set up the notebook if needed */
         /* This capplet has not been started yet.  We need to do that. */
         if ((data->id == -1) && (data->gde->exec_length)) {
+                GtkWidget *pixmap;
                 vbox = gtk_vbox_new(FALSE, 0);
+                gtk_signal_connect_after (GTK_OBJECT (vbox), "size_allocate", splash_size_allocate, NULL);
+                
                 data->socket = gtk_socket_new ();
                 gtk_signal_connect (GTK_OBJECT (data->socket), "destroy", capplet_close_callback, data);
                 separator = gtk_hseparator_new ();
@@ -158,23 +174,25 @@ launch_capplet (node_data *data, gboolean exec_new)
                 gtk_button_box_set_spacing (GTK_BUTTON_BOX (bbox), 5);
                 gtk_button_box_set_child_size (GTK_BUTTON_BOX (bbox), 5, -1);
                 gtk_container_set_border_width (GTK_CONTAINER (bbox), 5);
-
-                data->try_button = gtk_button_new_with_label (_("Try"));
+                
+                pixmap = gnome_stock_pixmap_widget (NULL, GNOME_STOCK_PIXMAP_JUMP_TO);
+                data->try_button = gnome_pixmap_button (pixmap, _("Try"));
                 gtk_widget_set_sensitive (data->try_button, FALSE);
                 gtk_container_add (GTK_CONTAINER (bbox), data->try_button);
                 gtk_signal_connect (GTK_OBJECT (data->try_button), "clicked", GTK_SIGNAL_FUNC (try_button_callback), data);
 
-                data->revert_button = gtk_button_new_with_label (_("Revert"));
+                pixmap = gnome_stock_pixmap_widget (NULL, GNOME_STOCK_PIXMAP_REVERT);
+                data->revert_button = gnome_pixmap_button (pixmap, _("Revert"));
                 gtk_widget_set_sensitive (data->revert_button, FALSE);
                 gtk_container_add (GTK_CONTAINER (bbox), data->revert_button);
                 gtk_signal_connect (GTK_OBJECT (data->revert_button), "clicked", GTK_SIGNAL_FUNC (revert_button_callback), data);
 
-                data->ok_button = gtk_button_new_with_label (_("OK"));
+                data->ok_button = gnome_stock_button (GNOME_STOCK_BUTTON_OK);
                 gtk_widget_set_sensitive (data->ok_button, FALSE);
                 gtk_container_add (GTK_CONTAINER (bbox), data->ok_button);
                 gtk_signal_connect (GTK_OBJECT (data->ok_button), "clicked", GTK_SIGNAL_FUNC (ok_button_callback), data);
 
-                data->cancel_button = gtk_button_new_with_label (_("Cancel"));
+                data->cancel_button = gnome_stock_button (GNOME_STOCK_BUTTON_CANCEL);
                 gtk_container_add (GTK_CONTAINER (bbox), data->cancel_button);
                 gtk_signal_connect (GTK_OBJECT (data->cancel_button), "clicked", GTK_SIGNAL_FUNC (cancel_button_callback), data);
                 /* put it all together */
@@ -219,11 +237,15 @@ launch_capplet (node_data *data, gboolean exec_new)
         }
         if (data->child != NULL) {
                 gtk_multiview_set_current (GTK_MULTIVIEW (multiview), data->child);
+                if (data->icon)
+                        gnome_window_icon_set_from_file (GTK_WINDOW (main_window),
+                                                         data->icon);
                 if (data->capplet && exec_new) {
                         GNOME_capplet_page_shown (data->capplet,
                                                   data->id,
                                                   &ev);
                 }
+                gtk_ctree_expand_recursive (data->ctree, data->node);
                 gtk_ctree_select (data->ctree, data->node);
         }
 }
@@ -382,6 +404,7 @@ close_capplet (gboolean show_splash, gpointer data)
         if (--page_count == 0) {
                 if (show_splash) {
                         gtk_multiview_set_current (GTK_MULTIVIEW (multiview), splash_screen);
+                        gnome_window_icon_set_from_default (GTK_WINDOW (main_window));
                         gtk_widget_hide (help_menu_item);
                 }
         } else if (show_splash) {
