@@ -140,8 +140,8 @@ capplet_corba_gtk_main (void)
         gtk_main();
 }
 
-static void
-do_quit(void)
+static gint
+do_quit(gpointer data)
 {
         /* This gross hack is here because just doing gtk_main_quit()
            won't exit a modal dialog that has popped up in a capplet,
@@ -153,17 +153,17 @@ do_quit(void)
 
         if(gtk_main_level() > 1)
                 gtk_idle_add(do_quit, NULL);
+                
+	return 0;            
 }
 
 void
 capplet_corba_gtk_main_quit (void)
 {
-        int i, n;
-
         CORBA_Object_release (control_center, &ev);
         CORBA_ORB_shutdown(orb, CORBA_FALSE, &ev);
 
-        do_quit();
+        do_quit(NULL);
 }
 
 void
@@ -172,6 +172,12 @@ capplet_corba_state_changed (gint id, gboolean undoable)
         GNOME_control_center_state_changed(control_center, id, undoable, &ev);
 }
 
+void
+capplet_corba_changes_are_immediate (gint id)
+{
+        GNOME_control_center_changes_are_immediate(control_center, id, &ev);
+}
+
 guint32
 _capplet_int_get_xid (gint cid)
 {
@@ -221,11 +227,8 @@ void *capplet_widget_corba_init(const char *app_id,
                                unsigned int flags,
                                poptContext *return_ctx)
 {
-        GoadServerList *gsdlist = NULL;
         PortableServer_ObjectId objid = {0, sizeof("capplet_interface"), "capplet_interface"};
         PortableServer_POA poa;
-        guint tempxid;
-        gint tempid;
         gchar *name;
 
         CORBA_exception_init(&ev);
