@@ -16,6 +16,7 @@ int server_register_capplet(PortableServer_Servant servant,
                         GNOME_capplet cap,
                         CORBA_Environment * env);
 void server_state_changed(PortableServer_Servant servant, CORBA_long id, CORBA_boolean undoable, CORBA_Environment * ev);
+void server_changes_are_immediate(PortableServer_Servant servant, CORBA_long id, CORBA_Environment * ev);
 void server_register_capplet_new (PortableServer_Servant servant,
                                   const GNOME_capplet cap,
                                   const CORBA_char * name,
@@ -44,7 +45,8 @@ POA_GNOME_control_center__epv control_center_epv =
         (gpointer)&server_register_capplet,
         (gpointer)&server_state_changed,
         (gpointer)&server_register_capplet_new,
-        (gpointer)&server_show_control_center
+        (gpointer)&server_show_control_center,
+	(gpointer)&server_changes_are_immediate
 };
 POA_GNOME_control_center__vepv poa_control_center_vepv = { &base_epv, &control_center_epv };
 POA_GNOME_control_center poa_control_center_servant = { NULL, &poa_control_center_vepv };
@@ -175,6 +177,21 @@ server_state_changed(PortableServer_Servant servant, CORBA_long id, CORBA_boolea
         gtk_ctree_node_set_foreground (nd->ctree, nd->node, &col);
 }
 
+void
+server_changes_are_immediate(PortableServer_Servant servant, CORBA_long id, CORBA_Environment * ev)
+{
+        node_data *nd = find_node_by_id (id);
+        if (nd == NULL){
+                g_warning ("couldn't find node %d\n",id);
+                g_warning ("this capplet will not function correctly...\n");
+                return;
+        }
+        gtk_widget_set_sensitive (nd->try_button, FALSE);
+        gtk_widget_set_sensitive (nd->revert_button, FALSE);
+        gtk_widget_set_sensitive (nd->cancel_button, FALSE);
+        gtk_widget_set_sensitive (nd->ok_button, TRUE);        
+}
+
 static void
 find_capplet (GtkCTree     *ctree,
               GtkCTreeNode *node,
